==> v1.2018.12.zip: plantuml/src/h/ST_dthold_s.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import smetana.core.UnsupportedStarStruct;
import smetana.core.UnsupportedStructAndPtr;
import smetana.core.__ptr__;
import smetana.core.amiga.StarStruct;

public class ST_dthold_s extends UnsupportedStructAndPtr {

	private final StarStruct parent;

	public ST_dthold_s() {
		this(null);
	}

	public ST_dthold_s(StarStruct parent) {
		this.parent = parent;
	}

	// "struct _dthold_s",
	// "{",
	// "Dtlink_t hdr",
	// "void*  obj",
	private final ST_dtlink_s hdr = new ST_dtlink_s(this);
	private __ptr__ obj;

	// "}");

	@Override
	public __ptr__ castTo(Class dest) {
		if (dest == _dthold_s.class) {
			return this;
		}
		if (dest == ST_dtlink_s.class) {
			return hdr;
		}
		return super.castTo(dest);
	}

	@Override
	public __ptr__ setPtr(String fieldName, __ptr__ newData) {
		if (fieldName.equals("obj")) {
			this.obj = newData;
			return this.obj;
		}
		return super.setPtr(fieldName, newData);
	}
	
	@Override
	public __ptr__ getPtr(String fieldName) {
		if (fieldName.equals("obj")) {
			return this.obj;
		}
		return super.getPtr(fieldName);
	}
}

// struct _dthold_s
// { Dtlink_t hdr; /* header */
// void* obj; /* user object */
// };

==> v1.2020.20.zip: plantuml/src/h/ST_dthold_s.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2022, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import smetana.core.UnsupportedStructAndPtr;
import smetana.core.__ptr__;
import smetana.core.amiga.StarStruct;

public class ST_dthold_s extends UnsupportedStructAndPtr {

	private final StarStruct parent;

	public ST_dthold_s() {
		this(null);
	}

	public ST_dthold_s(StarStruct parent) {
		this.parent = parent;
	}

	// "struct _dthold_s",
	// "{",
	// "Dtlink_t hdr",
	// "void*  obj",
	public final ST_dtlink_s hdr = new ST_dtlink_s(this);
	public __ptr__ obj;

	// "}");

	@Override
	public __ptr__ castTo(Class dest) {
		if (dest == ST_dthold_s.class) {
			return this;
		}
		if (dest == ST_dtlink_s.class) {
			return hdr;
		}
		return super.castTo(dest);
	}

	@Override
	public __ptr__ setPtr(String fieldName, __ptr__ newData) {
		if (fieldName.equals("obj")) {
			this.obj = newData;
			return this.obj;
		}
		return super.setPtr(fieldName, newData);
	}
	
}

// struct _dthold_s
// { Dtlink_t hdr; /* header */
// void* obj; /* user object */
// };
